@@ -2,7 +2,8 @@ import logging
 import os
 
 def veracode_logger(name):
-    formatter = logging.Formatter(fmt='%(asctime)s, %(levelname)s, %(message)s')
+    formatter = logging.Formatter(
+            fmt='%(asctime)s, %(levelname)s, %(message)s')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
     logger = logging.getLogger(name)
